@@ -7,6 +7,7 @@ from urllib3.exceptions import InsecureRequestWarning
 from requests.packages import urllib3
 from robot.libraries.BuiltIn import BuiltIn
 from robot.utils.dotdict import DotDict
+from pandas import to_datetime
 
 zoomba = BuiltIn()
 requests_lib = RequestsLibrary()
@@ -262,9 +263,10 @@ class APILibrary:
                 self._key_by_key_dict(key, value, actual_dictionary, expected_dictionary, unmatched_keys_list,
                                       ignored_keys, full_list_validation=full_list_validation, sort_lists=sort_lists,
                                       **kwargs)
-            elif isinstance(expected_dictionary[key], str) and not expected_dictionary[key].isdigit():
+            elif (isinstance(expected_dictionary[key], str) and not expected_dictionary[key].isdigit()) or isinstance(expected_dictionary[key], datetime.datetime):
                 try:
-                    parse(expected_dictionary[key])
+                    if not isinstance(expected_dictionary[key], datetime.datetime):
+                        parse(expected_dictionary[key])
                     self.date_string_comparator(value, actual_dictionary[key], key, unmatched_keys_list, **kwargs)
                 except (ValueError, TypeError):
                     if value == actual_dictionary[key]:
@@ -451,33 +453,17 @@ def _unmatched_list_check(unmatched_keys_list, current_unmatched_length, key, in
 
 def _date_format(date_string, key, unmatched_keys_list, date_type, date_format=None):
     formatted_date = None
-    if date_format is None:
+    if (date_format is None) and (date_string is not None):
         try:
-            formatted_date = datetime.datetime.strptime(date_string, '%Y-%m-%dT%H:%M:%S')
+            formatted_date = to_datetime(date_string).tz_localize(None).to_pydatetime()
         except ValueError:
-            try:
-                formatted_date = datetime.datetime.strptime(date_string, '%Y-%m-%dT%H:%M:%SZ')
-            except ValueError:
-                try:
-                    formatted_date = datetime.datetime.strptime(date_string, '%Y-%m-%dT%H:%M:%S.%f')
-                except ValueError:
-                    try:
-                        formatted_date = datetime.datetime.strptime(date_string, '%Y-%m-%dT%H:%M:%S.%fZ')
-                    except ValueError:
-                        try:
-                            formatted_date = parse(date_string, fuzzy=True)
-                            formatted_date = str(formatted_date).replace('+00:00', 'Z')
-                            formatted_date = formatted_date.replace(' ', 'T')
-                            formatted_date = datetime.datetime.strptime(formatted_date, "%Y-%m-%dT%H:%M:%S.%fZ")
-                        except ValueError:
-                            unmatched_keys_list.append(("------------------\nKey: " + str(key),
-                                                        date_type + " Date Not Correct Format:",
-                                                        "Expected Formats: %Y-%m-%dT%H:%M:%S",
-                                                        "                  %Y-%m-%dT%H:%M:%SZ",
-                                                        "                  %Y-%m-%dT%H:%M:%S.%f",
-                                                        "                  %Y-%m-%dT%H:%M:%S.%fZ",
-                                                        "Date: " + str(date_string)))
-
+            unmatched_keys_list.append(("------------------\nKey: " + str(key),
+                                        date_type + " Date Not Correct Format:",
+                                        "Expected Formats: %Y-%m-%dT%H:%M:%S",
+                                        "                  %Y-%m-%dT%H:%M:%SZ",
+                                        "                  %Y-%m-%dT%H:%M:%S.%f",
+                                        "                  %Y-%m-%dT%H:%M:%S.%fZ",
+                                        "Date: " + str(date_string)))
     else:
         try:
             formatted_date = datetime.datetime.strptime(date_string, date_format)
