@@ -5,6 +5,7 @@ from robot.api.deco import keyword
 from robot.libraries.Collections import Collections
 from time import time
 from robot.utils import is_string
+from selenium.webdriver.common.action_chains import ActionChains, ScrollOrigin
 import importlib
 
 # Importing ReactSelect
@@ -165,6 +166,26 @@ class GUILibrary(SeleniumLibrary):
         self.wait_for_and_focus_on_element(locator, timeout)
         self.select_from_list_by_index(locator, target)
 
+    @keyword("Mouse Scroll")
+    def mouse_scroll(self, x=0, y=0):
+        """Scroll the mouse wheel.\n
+        x: (int) Distance along X axis to scroll using the wheel. A negative value scrolls left.\n
+        y: (int) Distance along Y axis to scroll using the wheel. A negative value scrolls up.\n
+        """
+        actions = ActionChains(self.driver)
+        actions.scroll_by_amount(x, y).perform()
+
+    @keyword("Mouse Scroll Over Element")
+    def mouse_scroll_over_element(self, locator, x=0, y=0):
+        """Scroll the mouse wheel over an element indicated by `locator`.\n
+        locator:  (string) A selenium locator(CSS, XPATH, ID, NAME, etc)\n
+        x: (int) Distance along X axis to scroll using the wheel. A negative value scrolls left.\n
+        y: (int) Distance along Y axis to scroll using the wheel. A negative value scrolls up.\n
+        """
+        actions = ActionChains(self.driver)
+        scroll_origin = ScrollOrigin.from_element(self.find_element(locator))
+        actions.scroll_from_origin(scroll_origin, x, y).perform()
+
     @keyword("Wait For And Mouse Over")
     def wait_for_and_mouse_over(self, locator, timeout=None):
         """This is a series of chained Selenium keywords, that first waits for an element to be visible, then executes a
